==> risecx_chat_client-1.2.1%2B1.tar.gz: lib/widgets/chat/messages_types/received_message_widget.dart <==
import 'package:flutter/material.dart';
import 'package:risecx_chat_client/models/models.dart';
import 'package:risecx_chat_client/widgets/chat/messages_types/messages_types.dart';
import 'package:risecx_chat_client/widgets/widgets.dart';

class ReceivedMessageWidget extends StatefulWidget {
  final Map message;
  final Function onPayloadPress;
  final Function onMediaView;
  const ReceivedMessageWidget(
      {Key key, this.message, this.onPayloadPress, this.onMediaView})
      : super(key: key);

  @override
  _ReceivedMessageWidgetState createState() => _ReceivedMessageWidgetState();
}

class _ReceivedMessageWidgetState extends State<ReceivedMessageWidget> {
  String get _messageType {
    if (widget.message.containsKey('attachment') &&
        widget.message['attachment'] != null) {
      if (widget.message['attachment']['type'] == 'image') return 'image';
      if (widget.message['attachment']['kind'] == 'blocks-videos')
        return 'video';
      if (widget.message['attachment']['type'] == 'template')
        return widget.message['attachment']['payload']['template_type'];
    }

    if (widget.message.containsKey('text') &&
        widget.message.containsKey('quick_replies')) return 'quickResponse';
    if (widget.message.containsKey('text') && widget.message.containsKey('menus'))
      return 'menu';
    if (widget.message.containsKey('text') &&
        !widget.message.containsKey('quick_replies'))
      return 'text';
    else
      throw Exception('Unknown Message Type: ${widget.message}');
  }

  Widget messageWidget() {
    try {
      final key = GlobalKey();
      switch (_messageType) {
        case 'text':
          return TextMessageWidget(key: key, message: this.widget.message);
        case 'card':
          return Text('Card Message');
        case 'list':
          return ListMessageWidget(
            key: key,
            message: this.widget.message,
            onPayloadPress: widget.onPayloadPress,
          );
        case 'quickResponse':
          return QuickReplyMessageWidget(
            key: key,
            message: this.widget.message,
            onPayloadPress: widget.onPayloadPress,
          );
        case 'gallery':
          return Text('Gallery Message');
        case 'video':
          return VideoMessageWidget(
              key: key,
              message: this.widget.message,
              onMediaView: widget.onMediaView,
              onPayloadPress: widget.onPayloadPress);
        case 'image':
          return ImageMessageWidget(key: key, message: this.widget.message);
        case 'button':
          return ButtonMessageWidget(
            key: key,
            message: this.widget.message,
            onPayloadPress: widget.onPayloadPress,
          );
        case 'menu':
          return MenusMessageWidget(
            key: key,
            message: this.widget.message,
            onPayloadPress: widget.onPayloadPress,
          );
        case 'generic':
          return GenericMessageWidget(
            key: key,
            message: this.widget.message,
            onPayloadPress: widget.onPayloadPress,
          );
        default:
          return IgnorePointer();
      }
    } catch (e) {
      return IgnorePointer();
    }
  }

  @override
  Widget build(BuildContext context) {
    double cWidth = MediaQuery.of(context).size.width * 0.8;
    return Row(
      mainAxisAlignment: MainAxisAlignment.end,
      children: <Widget>[
        Container(
            padding: const EdgeInsets.all(16.0),
            width: cWidth,
            child: Bubble(
                margin: BubbleEdges.only(top: 10),
                nip: BubbleNip.rightTop,
                child: messageWidget())),
        Container(
          height: 50.0,
          width: 50.0,
          child: new CircleAvatar(
            backgroundColor: Colors.transparent,
            foregroundColor: Colors.red,
            radius: 100.0,
          ),
          decoration: BoxDecoration(
              border: Border.all(
                color: Colors.white,
                width: 3.0,
              ),
              shape: BoxShape.circle,
              image: new DecorationImage(
                image: _botAvatar,
                fit: BoxFit.cover,
              )),
        ),
      ],
    );
  }

  ImageProvider get _botAvatar => ConfigurationModel
              .instance.avatarImage.isNotEmpty &&
          ConfigurationModel.instance.avatarImage.contains('default_bot_avatar')
      ? AssetImage(ConfigurationModel.instance.avatarImage,
          package: 'risecx_chat_client')
      : AssetImage(ConfigurationModel.instance.avatarImage);
}

==> risecx_chat_client-1.2.3%2B1.tar.gz: lib/widgets/chat/messages_types/received_message_widget.dart <==
import 'package:flutter/material.dart';
import 'package:risecx_chat_client/models/models.dart';
import 'package:risecx_chat_client/widgets/chat/messages_types/message_widget.dart';
import 'package:risecx_chat_client/widgets/widgets.dart';

class ReceivedMessageWidget extends StatefulWidget {
  final Map message;
  final Function onPayloadPress;
  final Function onMediaView;
  const ReceivedMessageWidget(
      {Key key, this.message, this.onPayloadPress, this.onMediaView})
      : super(key: key);

  @override
  _ReceivedMessageWidgetState createState() => _ReceivedMessageWidgetState();
}

class _ReceivedMessageWidgetState extends State<ReceivedMessageWidget> {
  @override
  Widget build(BuildContext context) {
    double cWidth = MediaQuery.of(context).size.width * 0.8;
    return Row(
      mainAxisAlignment: MainAxisAlignment.start,
      children: <Widget>[
        SizedBox(width: 8),
        Container(
          height: 50.0,
          width: 50.0,
          child: new CircleAvatar(
            backgroundColor: Colors.transparent,
            foregroundColor: Colors.red,
            radius: 100.0,
          ),
          decoration: BoxDecoration(
              border: Border.all(
                color: Colors.white,
                width: 3.0,
              ),
              shape: BoxShape.circle,
              image: new DecorationImage(
                image: _botAvatar,
                fit: BoxFit.cover,
              )),
        ),
        Container(
            padding: const EdgeInsets.all(0),
            width: cWidth,
            child: Bubble(
                margin: BubbleEdges.only(top: 15, left: 5, right: 10),
                color: Color(0xFFEFF3F7),
                nip: null,
                child: MessageWidget(
                  message: widget.message,
                  onMediaView: widget.onMediaView,
                  onPayloadPress: widget.onPayloadPress,
                ))),
      ],
    );
  }

  ImageProvider get _botAvatar => ConfigurationModel
              .instance.avatarImage.isNotEmpty &&
          ConfigurationModel.instance.avatarImage.contains('default_bot_avatar')
      ? AssetImage(ConfigurationModel.instance.avatarImage,
          package: 'risecx_chat_client')
      : AssetImage(ConfigurationModel.instance.avatarImage);
}
